@@ -139,6 +139,15 @@ class CircuitTemplate(AbstractBaseTemplate):
         self._vectorization_indices = {}
         self._state_var_indices = {}
 
+    def __getitem__(self, item):
+        """Attempts to return the node with name `item`.
+        """
+        try:
+            return self.nodes[item]
+        except KeyError:
+            warn(PyRatesWarning(f"Node with name {item} was not found on {self.name}."))
+            return
+
     def to_yaml(self, path, **kwargs) -> None:
         """Shorthand to save the `CircuitTemplate` to a yaml file. After that call, either a new YAML file has been
         created including all template definitions required to reconstruct the `CircuitTemplate` instance, or additional
@@ -578,7 +587,18 @@ class CircuitTemplate(AbstractBaseTemplate):
             net.clear()
         self._ir = net._ir
 
-        return func, args, arg_names, state_var_indices
+        # map the backend variable names to the frontend variable names
+        state_var_map = {}
+        for v, idx in state_var_indices.items():
+            v_new = net._ir.get_frontend_varname(v)
+            state_var_map[v_new] = idx
+        args_mapped = []
+        for arg in arg_names:
+            try:
+                args_mapped.append(net._ir.get_frontend_varname(arg))
+            except (ValueError, KeyError):
+                args_mapped.append(arg)
+        return func, args, tuple(args_mapped), state_var_map
 
     def apply(self, adaptive_steps: bool = None, label: str = None, node_values: dict = None, edge_values: dict = None,
               vectorize: bool = True, verbose: bool = True, **kwargs) -> None:
@@ -703,6 +723,11 @@ class CircuitTemplate(AbstractBaseTemplate):
                 # project inputs to edge ir node
                 if not sources:
                     i_, in_var = edge_ir.inputs.copy().popitem()
+                    if i_ == source.split("/")[-1]:
+                        raise PyRatesException(f"The input variable of an edge operator that a source node projects to "
+                                               f"cannot be the same as the name of the output variable on the node. "
+                                               f"Please rename either the node output variable {source} or the edge "
+                                               f"input variable {edge_ir.label}/{in_var[0]}.")
                     sources[f"{edge_ir.label}/{in_var[0]}"] = ['source']*len(source_idx)
 
                 # collect new edge attributes
